searchData={"items":[{"type":"module","title":"EasyRpc","doc":"Documentation for `EasyRpc`.","ref":"EasyRpc.html"},{"type":"function","title":"EasyRpc.hello/0","doc":"Hello world.","ref":"EasyRpc.html#hello/0"},{"type":"function","title":"Examples - EasyRpc.hello/0","doc":"iex> EasyRpc.hello()\n    :world","ref":"EasyRpc.html#hello/0-examples"},{"type":"module","title":"EasyRpc.RpcWrapper","doc":"This module provides a wrapper for RPC (Remote Procedure Call) functionalities.\nIt includes functions to facilitate communication between different parts of the system\nor between different systems over a network.","ref":"EasyRpc.RpcWrapper.html"},{"type":"module","title":"Configuration for RpcWrapper - EasyRpc.RpcWrapper","doc":"Put config to config.exs file, and use it in your module by using RpcWrapper.\nUser need separate config for each wrapper, and put it in config.exs\n\n`:nodes` List of nodes, or {module, function, args} to get nodes.\n`:module` Module of remote functions on remote node.\n`:error_handling` Enable error handling (catch all) or not.\n`:select_node_mode` Select node mode, support for random, round_robin, hash.\n`:functions` list of functions, each function is a tuple {function_name, arity} or {function_name, new_name, arity, opts}.\n`:opts` Map of options, including new_name, retry, error_handling. Ex: [new_name: :clear_data, retry: 3, error_handling: false]\n\n```Elixir\nconfig :app_name, :wrapper_name,\n  nodes: [:\"test1@test.local\"],\n  # or nodes: {MyModule, :get_nodes, []}\n  error_handling: true, # enable error handling, global setting for all functions.\n  select_node_mode: :random, # select node mode, global setting for all functions.\n  module: TargetApp.RemoteModule,\n  functions: [\n    # {function_name, arity}\n    {:get_data, 1},\n    {:put_data, 1},\n    # {function_name, arity, opts}\n    {:clear, 2, [new_name: :clear_data, retry: 3, error_handling: false]},\n  ]\n```\n\nusage:\nby using RpcWrapper in your module, you can call remote functions as local functions.\n\n:otp_app, name of application will add config\n:config_name, name of config in application\n\n```Elixir\ndefmodule DataHelper do\nuse EasyRpc.RpcWrapper,\n  otp_app: :app_name,\n  config_name: :account_wrapper\n\ndef process_remote() do\n  case get_data(\"key\") do\n    {:ok, data} ->\n      # do something with data\n    {:error, reason} ->\n      # handle error\n  end\nend\n```","ref":"EasyRpc.RpcWrapper.html#module-configuration-for-rpcwrapper"},{"type":"function","title":"EasyRpc.RpcWrapper.get_config!/3","doc":"","ref":"EasyRpc.RpcWrapper.html#get_config!/3"},{"type":"function","title":"EasyRpc.RpcWrapper.rpc_call/2","doc":"rpc wrapper, support for define macro.","ref":"EasyRpc.RpcWrapper.html#rpc_call/2"},{"type":"function","title":"EasyRpc.RpcWrapper.rpc_call_error_handling/2","doc":"rpc wrapper, support for define macro.","ref":"EasyRpc.RpcWrapper.html#rpc_call_error_handling/2"},{"type":"exception","title":"EasyRpc.RpcWrapper.RpcWrapperError","doc":"","ref":"EasyRpc.RpcWrapper.RpcWrapperError.html"},{"type":"function","title":"EasyRpc.RpcWrapper.RpcWrapperError.raise_error/1","doc":"","ref":"EasyRpc.RpcWrapper.RpcWrapperError.html#raise_error/1"},{"type":"extras","title":"Readme","doc":"[![Docs](https://img.shields.io/badge/api-docs-green.svg?style=flat)](https://hexdocs.pm/easy_rpc)\n[![Hex.pm](https://img.shields.io/hexpm/v/easy_rpc.svg?style=flat&color=blue)](https://hex.pm/packages/easy_rpc)\n\n# EasyRpc\n\nThis library help developer easy to wrap a remote procedure call (rpc, library uses Erlang `:erpc` module).","ref":"readme.html"},{"type":"extras","title":"Installation - Readme","doc":"Adding `easy_rpc` library to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:easy_rpc, \"~> 0.1.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Readme","doc":"Follow steps","ref":"readme.html#usage"},{"type":"extras","title":"Add config to config.exs - Readme","doc":"Put config to config.exs file, and use it in your module by using RpcWrapper.\nUser need separate config for each wrapper, and put it in config.exs\n\n```Elixir\nconfig :app_name, :wrapper_name,\n  nodes: [:\"test1@test.local\"],\n  # or nodes: {MyModule, :get_nodes, []}\n  error_handling: true, # enable error handling, global setting for all functions.\n  select_node_mode: :random, # select node mode, global setting for all functions.\n  module: TargetApp.Interface.Api,\n  functions: [\n    # {function_name, arity}\n    {:get_data, 1},\n    {:put_data, 1},\n    # {function_name, arity, opts}\n    {:clear, 2, [new_name: :clear_data, retry: 3, error_handling: false]},\n  ]\n```","ref":"readme.html#add-config-to-config-exs"},{"type":"extras","title":"Add to local module - Readme","doc":"by using `use EasyRpc.RpcWrapper` in your module, you can call remote functions as local functions.\n\n```Elixir\ndefmodule DataHelper do\nuse EasyRpc.RpcWrapper,\n  otp_app: :app_name,\n  config_name: :account_wrapper\n\ndef process_remote() do\n  case get_data(\"key\") do\n    {:ok, data} ->\n      # do something with data\n    {:error, reason} ->\n      # handle error\n  end\nend\n```\n\nFor details please go to module's docs.","ref":"readme.html#add-to-local-module"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}